(execute-command command)(execute-command command opts)Inputs: ([command :- schema/Str] [command :- schema/Str opts :- ExecutionOptions]) Returns: ExecutionResult
Execute the specified fully qualified command (string) and any included command-arguments (vector of strings) and return the exit-code (integer), the contents of the stdout (string) and stderr (string) for the command, and whether the process was killed for exceeding its timeout (boolean).
See execute-command-streamed for details on the optional :timeout-ms entry in opts and the :timed-out entry in the result.
Inputs: ([command :- schema/Str] [command :- schema/Str opts :- ExecutionOptions]) Returns: ExecutionResult Execute the specified fully qualified command (string) and any included command-arguments (vector of strings) and return the exit-code (integer), the contents of the stdout (string) and stderr (string) for the command, and whether the process was killed for exceeding its timeout (boolean). See execute-command-streamed for details on the optional :timeout-ms entry in opts and the :timed-out entry in the result.
(execute-command-streamed command)(execute-command-streamed command opts)Inputs: ([command :- schema/Str] [command :- schema/Str opts :- ExecutionOptions]) Returns: ExecutionResultStreamed
Execute the specified fully qualified command (string) and any included command-arguments (vector of strings) and return the exit-code (integer), the contents of the stdout (stream) and stderr (string) for the command, and whether the process was killed for exceeding its timeout (boolean).
If opts includes a :timeout-ms value, the process will be forcibly terminated if it has not completed within that many milliseconds, and :timed-out will be true in the result. If :timeout-ms is not provided (the default), this call blocks on the process indefinitely, as before, and :timed-out will always be false.
Inputs: ([command :- schema/Str] [command :- schema/Str opts :- ExecutionOptions]) Returns: ExecutionResultStreamed Execute the specified fully qualified command (string) and any included command-arguments (vector of strings) and return the exit-code (integer), the contents of the stdout (stream) and stderr (string) for the command, and whether the process was killed for exceeding its timeout (boolean). If opts includes a :timeout-ms value, the process will be forcibly terminated if it has not completed within that many milliseconds, and :timed-out will be true in the result. If :timeout-ms is not provided (the default), this call blocks on the process indefinitely, as before, and :timed-out will always be false.
A map that contains the details of the result of executing a command. :timed-out is true if the process was forcibly terminated for exceeding a :timeout-ms configured via ExecutionOptions; false otherwise (including when the process completed with a non-zero exit code, or when no :timeout-ms was configured).
A map that contains the details of the result of executing a command. :timed-out is true if the process was forcibly terminated for exceeding a :timeout-ms configured via ExecutionOptions; false otherwise (including when the process completed with a non-zero exit code, or when no :timeout-ms was configured).
A map that contains the details of the result of executing a command with stdout as a stream. :timed-out has the same meaning as in ExecutionResult.
A map that contains the details of the result of executing a command with stdout as a stream. :timed-out has the same meaning as in ExecutionResult.
(java-exe-options {:keys [env in cwd timeout-ms]})Inputs: [{:keys [env in cwd timeout-ms]} :- ExecutionOptions] Returns: ShellUtils$ExecutionOptions
Inputs: [{:keys [env in cwd timeout-ms]} :- ExecutionOptions]
Returns: ShellUtils$ExecutionOptions(validate-command! command)Inputs: [command :- schema/Str]
Checks the command string to ensure that it is an absolute path, executable and that the file exists. An exception is thrown if any of those are not the case.
Inputs: [command :- schema/Str] Checks the command string to ensure that it is an absolute path, executable and that the file exists. An exception is thrown if any of those are not the case.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |